@@ -873,7 +873,10 @@ void	DirListCD(list<MatchInfo> &match_list, const string &init_pos,
 void	CD(const string &linktext, bool entire_tree)
 {
 	LoadDirFile(1);
+
 	HyperDraw *drawObj = 0;
+	list<MatchInfo>	match_list;			// Must match lifetime
+							// of drawObj!
 
 	if (saveCwd.size())				// Current directory is available
 		FindDir(saveCwd, false);
@@ -886,7 +889,6 @@ void	CD(const string &linktext, bool entire_tree)
 	if (linktext.size()) {				// kcd DIR
 
 		ImportBookmarks("");
-		list<MatchInfo>	match_list;
 
 		if (entire_tree)			// Ignore bookmarks
 							// We add current
@@ -926,7 +928,6 @@ void	CD(const string &linktext, bool entire_tree)
 				break;
 			}
 		}
-
 							// +1 because of current
 							// directory in match_list
 		if (match_list.size() > static_cast<size_t>(kcdConfig.cfgShowListThreshold)
