@@ -1,6 +1,6 @@
 /*
 	kcdmain.cc	Kriang's Change Directory
-	Copyright (c) 1996,1997,1998,1999,2000,2001,2002 Kriang Lerdsuwanakij
+	Copyright (c) 1996,1997,1998,1999,2000,2001,2002,2003 Kriang Lerdsuwanakij
 	email:		lerdsuwa@users.sourceforge.net
 
 	This program is free software; you can redistribute it and/or modify
@@ -72,7 +72,7 @@ void	PrintBanner()
 
 	cout << progName << ' ' << version
 	     << _(" - Kriang's Change Directory\n");
-	gtout(cout, _("(c) 1996-9,2000-1,2002 Kriang Lerdsuwanakij    "
+	gtout(cout, _("(c) 1996-9,2000-2,2003 Kriang Lerdsuwanakij    "
 		      "Release date: %$\n\n"))
 	     << my_strftime(_("%b %e, %Y"), &rel_time);
 
@@ -451,9 +451,9 @@ void	mainReal(int argc, char *argv[])
 				if (argcLeft >= 3)
 					throw ErrorGenericCommandLine(_("too many arguments for `-bx\'"));
 				else if (argcLeft == 2)
-					ExportBookmarks(argv[argcCur+1], true);
+					ExportBookmarks(argv[argcCur+1]);
 				else
-					ExportBookmarks("", true);
+					ExportBookmarks("");
 				return;
 			}
 						// Use entire tree
